function createPDB( pdbStructure,filPath )
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% write a pdb file.
% input:
%   pdbStructure
%   filPath
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   fid=fopen(filPath,'w');
   PDB_Format_Dec = '%-6s%5i %-4s%1s%-4s%1s%4s%1s   %8.3f%8.3f%8.3f%6.2f%6.2f      %4s%2s%2s\n'; % atomNumber within 99999
   PDB_Format_hex = '%-6s%5X %-4s%1s%-4s%1s%4s%1s   %8.3f%8.3f%8.3f%6.2f%6.2f      %4s%2s%2s\n'; % atomNumber within 99999
   atomname_Format_3 = ' %-3s';
   CRYST1 = 'CRYST1%9.3f%9.3f%9.3f%7.2f%7.2f%7.2f P 1\n';
   if ~iscell(pdbStructure)
        atomnames = {pdbStructure.atmname};
        is4 = cellfun(@length,atomnames) > 3;
        atomnames(~is4) = cellfun(@(x) sprintf(atomname_Format_3,x),atomnames(~is4),'uniformoutput',0);
        crd = getCoord(pdbStructure);
        cubSize = max(crd,[],1) - min(crd,[],1);
        fprintf(fid,CRYST1,cubSize(1),cubSize(2),cubSize(3),90,90,90);
        for i=1:length(pdbStructure)
            if pdbStructure(i).atomno > 99999
                PDB_Format = PDB_Format_hex;
            else
                PDB_Format = PDB_Format_Dec;
            end
            fprintf(fid,PDB_Format,pdbStructure(i).record,...
                                    pdbStructure(i).atomno,...
                                    atomnames{i},...
                                    pdbStructure(i).alternate,...
                                    pdbStructure(i).resname,...
                                    pdbStructure(i).subunit,...
                                    pdbStructure(i).resno,...
                                    pdbStructure(i).iCode,...
                                    pdbStructure(i).coord(1),...
                                    pdbStructure(i).coord(2),...
                                    pdbStructure(i).coord(3),...
                                    pdbStructure(i).occupancy,...
                                    pdbStructure(i).bval,...
                                    pdbStructure(i).segment,...
                                    pdbStructure(i).elementSymbol,...
                                    pdbStructure(i).charge);
        end 
   else
       for j=1:length(pdbStructure)
           fprintf(fid,'MODEL       %2i\n',j);
           model=pdbStructure{j};
            atomnames = {model.atmname};
            is4 = cellfun(@length,atomnames) > 3;
            atomnames(~is4) = cellfun(@(x) sprintf(atomname_Format_3,x),atomnames(~is4),'uniformoutput',0);
           for i=1:length(model)
                if model(i).atomno > 99999
                    PDB_Format = PDB_Format_hex;
                else
                    PDB_Format = PDB_Format_Dec;
                end
                fprintf(fid,PDB_Format, model(i).record,...
                                                        model(i).atomno,...
                                                        atomnames{i},...
                                                        model(i).alternate,...
                                                        model(i).resname,...
                                                        model(i).subunit,...
                                                        model(i).resno,...
                                                        model(i).iCode,...
                                                        model(i).coord(1),...
                                                        model(i).coord(2),...
                                                        model(i).coord(3),...
                                                        model(i).occupancy,...
                                                        model(i).bval,...
                                                        model(i).segment,...
                                                        model(i).elementSymbol,...
                                                        model(i).charge);
           end
           fprintf(fid,'ENDMDL\n');
       end
       fprintf(fid,'\n');
   end
   fprintf(fid,'END');
fclose(fid);
end

